@@ -12,9 +12,9 @@ use App::TimelogTxt::Day;
 use App::TimelogTxt::File;
 use App::TimelogTxt::Event;
 
-our $VERSION = '0.03_2';
-
+our $VERSION = '0.03_3';
 
+# Initial configuration information.
 my %config = (
     editor => '',
     dir    => '',
@@ -22,24 +22,25 @@ my %config = (
 );
 my $config_file = "$ENV{HOME}/.timelogrc";
 
+# Dispatch table for commands
 my %commands = (
     'start' => {
         code     => \&start_event,
         clue     => 'start {event description}',
         abstract => 'Start timing a new event.',
-        help     => 'Stop last event and start timing a new event.',
+        help     => 'Stop the current event and start timing a new event.',
     },
     App::TimelogTxt::Utils::STOP_CMD() => {
         code => sub { my $app = shift; log_event( $app, App::TimelogTxt::Utils::STOP_CMD() ); },
         clue => App::TimelogTxt::Utils::STOP_CMD(),
-        abstract => 'Stop timing last event.',
-        help     => 'Stop timing last event.',
+        abstract => 'Stop timing the current event.',
+        help     => 'Stop timing the current event.',
     },
     'push' => {
         code     => \&push_event,
         clue     => 'push {event description}',
-        abstract => 'Save current event and start timing new.',
-        help     => 'Save last event on stack and start timing new event.',
+        abstract => 'Save the current event and start timing new.',
+        help     => 'Save the current event on stack and start timing new event.',
     },
     'pop' => {
         code     => \&pop_event,
@@ -51,7 +52,7 @@ my %commands = (
         code     => \&drop_event,
         clue     => 'drop [all|{n}]',
         abstract => 'Drop items from stack.',
-        help     => 'Drop one or more items from top of event stack, or all
+        help     => 'Drop one or more events from top of event stack, or all
 if argument supplied.',
     },
     'ls' => {
@@ -98,6 +99,8 @@ if argument supplied.',
     },
 );
 
+# Sub class of App::CmdDispatch that initializes configuration information
+# specific to this program. It also provides access to that configuration.
 {
     package Timelog::CmdDispatch;
     use base 'App::CmdDispatch';
@@ -116,18 +119,30 @@ if argument supplied.',
     {
         my ($self) = @_;
         my $config = $self->get_config();
+        my $home = _home();
 
         $config->{editor} ||= $config{editor} || $ENV{'VISUAL'} || $ENV{'EDITOR'} || '/usr/bin/vim';
-        $config->{dir}    ||= $config{dir} || "$ENV{HOME}/timelog";
+        $config->{dir}    ||= $config{dir} || "$home/timelog";
         $config->{defcmd} ||= $config{defcmd} || App::TimelogTxt::Utils::STOP_CMD();
-        $config->{'dir'} =~ s/~/$ENV{HOME}/;
+        $config->{dir} =~ s/~/$home/;
         foreach my $d ( [qw/logfile timelog.txt/], [qw/stackfile stack.txt/] )
         {
             $config->{ $d->[0] } = "$config->{'dir'}/$d->[1]";
-            $config->{ $d->[0] } =~ s/~/$ENV{HOME}/;
+            $config->{ $d->[0] } =~ s/~/$home/;
         }
         return;
     }
+
+    sub _home
+    {
+        return $ENV{HOME} if defined $ENV{HOME};
+        if( $^O eq 'MSWin32' )
+        {
+            return "$ENV{HOMEDRIVE}$ENV{HOMEPATH}" if defined $ENV{HOMEPATH};
+            return $ENV{USERPROFILE} if defined $ENV{USERPROFILE};
+        }
+        return '/';
+    }
 }
 
 sub run
@@ -158,6 +173,8 @@ or a day name: yesterday, today, or sunday .. saturday.\n",
     return;
 }
 
+# Command handlers
+
 sub log_event
 {
     my $app    = shift;
@@ -174,14 +191,6 @@ sub edit_logfile
     return;
 }
 
-sub _each_logline
-{
-    my ( $app, $code ) = @_;
-    open my $fh, '<', $app->_logfile;
-    $code->() while( <$fh> );
-    return;
-}
-
 sub list_events
 {
     my ( $app, $day ) = @_;
@@ -245,56 +254,6 @@ sub report_hours
     return;
 }
 
-sub extract_day_tasks
-{
-    my ( $app, $day, $eday ) = @_;
-
-    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
-    die "No day provided.\n" unless defined $stamp;
-    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
-    my ( $summary, %last, @summaries );
-    my $event;
-    my $prev_stamp = '';
-
-    open my $fh, '<', $app->_logfile;
-    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
-
-    while( defined( $_ = $file->readline ) )
-    {
-        eval {
-            $event = App::TimelogTxt::Event->new_from_line( $_ );
-        } or next;
-        if( $prev_stamp ne $event->stamp )
-        {
-            my $new_stamp = $event->stamp;
-            if( $summary and !$event->is_stop() )
-            {
-                $summary->update_dur( \%last, $new_stamp );
-                %last = ();
-            }
-            $summary = App::TimelogTxt::Day->new( $new_stamp );
-            push @summaries, $summary;
-            $prev_stamp = $new_stamp;
-        }
-        $summary->set_start( $event->epoch );
-        $summary->update_dur( \%last, $event->epoch );
-        $summary->start_task( $event );
-        %last = ($event->is_stop() ? () : $event->snapshot );
-    }
-
-    return [] unless $summary;
-
-    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !$event->is_stop() )
-        ? time
-        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
-
-    $summary->update_dur( \%last, $end_time );
-
-    return if $summary->is_empty;
-
-    return \@summaries;
-}
-
 sub start_event
 {
     my ( $app, @event ) = @_;
@@ -302,13 +261,6 @@ sub start_event
     return;
 }
 
-sub _stack
-{
-    my ($app) = @_;
-    require App::TimelogTxt::Stack;
-    return App::TimelogTxt::Stack->new( $app->_stackfile );
-}
-
 sub push_event
 {
     my ( $app, @event ) = @_;
@@ -343,10 +295,79 @@ sub list_stack
     my ($app) = @_;
     return unless -f $app->_stackfile;
     my $stack = _stack( $app );
-    $stack->list();
+    $stack->list( \*STDOUT );
     return;
 }
 
+# Extract the daily events from the timelog.txt file and generate the list of Day
+# objects that encapsulates them.
+
+sub extract_day_tasks
+{
+    my ( $app, $day, $eday ) = @_;
+
+    my $stamp = App::TimelogTxt::Utils::day_stamp( $day );
+    die "No day provided.\n" unless defined $stamp;
+    my $estamp = App::TimelogTxt::Utils::day_end( $eday ? App::TimelogTxt::Utils::day_stamp( $eday ) : $stamp );
+    my ( $summary, $last, @summaries );
+    my $prev_stamp = '';
+
+    open my $fh, '<', $app->_logfile;
+    my $file = App::TimelogTxt::File->new( $fh, $stamp, $estamp );
+
+    use Data::Dumper;
+    while( defined( my $line = $file->readline ) )
+    {
+        my $event;
+        eval {
+            $event = App::TimelogTxt::Event->new_from_line( $line );
+        } or next;
+        if( $prev_stamp ne $event->stamp )
+        {
+            my $new_stamp = $event->stamp;
+            if( $summary and !$event->is_stop() )
+            {
+                $summary->update_dur( $last, $event->epoch );
+                $last = undef;
+            }
+            $summary = App::TimelogTxt::Day->new( $new_stamp );
+            push @summaries, $summary;
+            $prev_stamp = $new_stamp;
+        }
+        $summary->update_dur( $last, $event->epoch );
+        $summary->start_task( $event );
+        $last = ($event->is_stop() ? undef : $event );
+    }
+
+    return [] unless $summary;
+    my $end_time = ( App::TimelogTxt::Utils::is_today( $day ) and !($last and $last->is_stop()) )
+        ? time
+        : App::TimelogTxt::Utils::stamp_to_localtime( $estamp );
+
+    $summary->update_dur( $last, $end_time );
+
+    return if $summary->is_empty;
+
+    return \@summaries;
+}
+
+# Utility functions
+
+sub _each_logline
+{
+    my ( $app, $code ) = @_;
+    open my $fh, '<', $app->_logfile;
+    $code->() while( <$fh> );
+    return;
+}
+
+sub _stack
+{
+    my ($app) = @_;
+    require App::TimelogTxt::Stack;
+    return App::TimelogTxt::Stack->new( $app->_stackfile );
+}
+
 sub _get_last_event
 {
     my ( $app ) = @_;
@@ -366,7 +387,7 @@ App::TimelogTxt - Core code for timelog utility.
 
 =head1 VERSION
 
-This document describes App::TimelogTxt version 0.03_2
+This document describes App::TimelogTxt version 0.03_3
 
 =head1 SYNOPSIS
 
@@ -376,21 +397,118 @@ This document describes App::TimelogTxt version 0.03_2
 =head1 DESCRIPTION
 
 This module encapsulates all of the functionality of the timelog application.
+This module delegates much of the heavy lifting to other modules. It does
+handle the UI work and the configuration file.
 
 =head1 INTERFACE
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
+At the moment, the only real interface to this file is the C<run> command.
+In case this becomes more generally useful somehow, I'll go ahead and document
+the other public methods.
 
+In the methods below, the C<$app> parameter is an object of the class
+C<Timelog::CmdDispatch>. This is a subclass of L<App::CmdDispatch> that adds
+support needed for some of our configuration.
+
+=head2 run()
+
+=head2 log_event( $app, @event );
+
+Add the specified event to the end of timelog.txt
+
+=head2 edit_logfile( $app )
+
+Implementation of the 'edit' command.
+
+=head2 list_events( $app, $day )
+
+Implementation of the 'ls' command.
+
+=head2 list_projects( $app )
+
+Implementation of the 'lsproj' command.
+
+=head2 daily_report( $app, $day, $end_day )
+
+Implementation of the 'report' command.
+
+=head2 daily_summary( $app, $day, $end_day )
+
+Implementation of the  'summary' command.
+
+=head2 report_hours( $app, $day, $end_day )
+
+Implementation of the 'hours' command.
+
+=head2 extract_day_tasks( $app, $day, $end_day )
+
+Read the timelog.txt file and create an array of L<App::TimelogTxt::Day>
+objects that contain the information for the days from C<$day> to C<$end_day>.
+
+=head2 start_event( $app, @event )
+
+Implementation of the 'start' command.
+
+=head2 push_event( $app, @event )
+
+Implementation of the 'push' command.
+
+=head2 pop_event( $app )
+
+Implementation of the 'pop' command.
+
+=head2 drop_event( $app, $arg )
+
+Implementation of the 'drop' command.
+
+=head2 list_stack( $app )
+
+Implementation of the 'lstk' command.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
 App::TimelogTxt requires no environment variables.
 App::TimelogTxt will use the file ~/.timelogrc if it exists.
 
+The configuration file is expected to contain data in two major parts:
+
+=head2 General Configuration
+
+The first section defined general configuration information in a key=value
+format. The recognized keys are:
+
+=over 4
+
+=item editor
+
+The editor to use when opening the timelog file with the C<edit> command.
+If not specified, it will use the value of either the VISUAL or EDITOR
+environment variables. If non are found, it will default to C<vim>.
+
+=item dir
+
+The directory in which to find the timelog data files. Defaults to the
+C<timelog> directory in the user's home directory.
+
+=item defcmd
+
+The default command to by used if none is supplied to timelog. By default,
+this is the 'stop' command.
+
+=back
+
+=head2 Command Aliases
+
+The config file may also contain an '[alias]' section that defines command
+aliases. Each alias is defined as a C<shortname=expanded string>
+
+For example, if you regularly need to make entries for reading email and
+triaging bug reports you might want the following in your configuration.
+
+  [alias]
+    email = start +Misc @Email
+    triage = start +BugTracker @Triage
+
 =head1 DEPENDENCIES
 
 App::CmdDispatch, Getopt::Long, autodie.
@@ -420,7 +538,6 @@ Copyright (c) 2013, G. Wade Johnson C<< <gwadej@cpan.org> >>. All rights reserve
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
